---
title: "Does the Constitution Protect Free Speech?"
author: "Herbert Goodrich"
image: img/herbert-goodrich.jpg
era: "Twentieth Century"
topic: "Free Speech"
draft: false
---

*The following is a [paper published in the Michigan Law Review, in 1921](https://www.jstor.org/stable/1276931). It provides excellent commentary and context on Holme’s “clear and present danger” standard, the effect of the Espionage Act on the First Amendment, and the general mood of the court, at the end of the First World War.*

**Does The Constitution Protect Free Speech?**

MANY thoughtful men and women, witnessing the suppression of speech, by means both judicial and extra-judicial, in the period through which we have just passed, have reluctantly concluded that our hard won right of freedom of speech has been lost, swept away in the flood tide of war enthusiasm. They point to the example of the recent candidate for the presidency, Eugene Debs, who is still confined in a federal prison for words he uttered during the war. They call attention to the fact that the fate of Mr. Debs is no worse than that of scores of other persons, members of his and other minority groups, who have gone to jail since April, 1917, for giving utterance to unpopular opinions. Finally, they show us a widespread wave of “anti-disturbance” legislation among our legislatures during and immediately after the war.

Things have now quieted down. We no longer jump with apprehension at hearing the word “Bolshevist.” Attention is turning to the multitude of questions arising out of our return to a *de facto* if not a *de jure*, state of peace. In the meantime, our federal Supreme Court has had occasion, in cases arising under the **Espionage Act**, to give us some authoritative expositions of the legal meaning of that freedom of speech guaranteed by our Constitution. It seems desirable to see how far these decisions have taken us in setting out the limits of lawful speech, before our interest is entirely diverted to matters more pressing.

> “Congress shall make no law… abridging the freedom of speech or of the press.”

These are the unyielding words of the First Amendment, the first of the federal “Bill of Rights.” Similar provisions are to be found in nearly all State constitutions. Do the words mean, literally,’that neither Congress nor legislature can punish words alone, no matter what they are? A few examples will show that such an absolute conception of the meaning of freedom of speech is untenable. A man might persuade another to murder his enemy, he might defame his neighbor, he might perjure himself on the witness stand, he might induce a soldier to desert his post. Surely, constitutional protection was not meant for him.

But if a definition of free speech is not to be an absolute one, applicable to all words, what is it to be? So far as the question involves legal rights secured by a constitution, we naturally turn to the decisions of courts of final authority whose function is to interpret the Constitution. The legal significance of many clauses our federal Constitution has been determined in this fashion. The “commerce clause,” by which the Congress was given authority to regulate interstate commerce, and the “due process of law” clause of the Fourteenth Amendment are examples which readily suggest themselves.

With the free speech provision we have no such help. The Supreme Court has said that the Bill of Rights in the Constitution was designed simply to embody certain general guaranties inherited from English ancestors, which had always been subject to certain well-defined exceptions arising from necessity. So the free speech clause does not prevent the exclusion of lottery tickets or obscene matter from the mails; neither does it privilege words interfering with pending proceedings in a court of justice. No doubt we may safely say that speech which would be a common law tort or crime is still a basis of liability despite a free speech clause. But until the recent cases under the war-time Espionage Act came before the Supreme Court there was little to mark out for us what the limits of free speech are. Standard treatises on constitutional law devote little space to a discussion of the First Amendment, and their authors had little on which to base such discussion. **The Sedition Act of 1798** made it a criminal offense to publish false matter against “*either house of the Congress of the United States or the president of the United States with intent to bring them or either of them into contempt or disrepute.*” There were convictions under this act shocking to one’s sense of justice, but it expired by its own limitation before Chief Justice Marshall reached the Supreme Bench, and before the court had announced its authority to declare an act of Congress unconstitutional. Good authority, Jefferson included, believed the law in conflict with the Constitution. Again, in 1861, an act punished conspiracy to levy war against the United States, but nothing decided under it gives an authoritative exposition of the right of free speech.

Of more than usual interest, then, are the cases which our Supreme Court has decided under the recent **Espionage Act**. Not all decisions are worthy of notice here, for some of them went off on technical points. Others are very important. As might be expected, some of them have been the subject of hot controversy. The brilliant dissent of Mr. Justice Holmes in the famous **Abrams v. United States** case, of which more hereafter, was called by different (and differing) writers in one of our best legal periodicals “*shocking in its obtuse indifference to the vital issues at stake in August, 1918, and… ominous in its portent of like indifference to pending and coming issues,*“‘ and “*a literary and judicial classic*” the courageous language of which “*saves from pessimism those who still have faith in our Bill of rights.*“

**The Espionage Act** was passed by Congress June 15, I917. Title One, Section Three of this statute made it a crime, while the United States is at war, (1) to make false statements with intent to interfere with the operation of our fighting forces; (2) to cause or attempt to cause disloyalty or insubordination in army or navy; (3) willfully to obstruct or attempt to obstruct recruiting. In I918 the list of crimes was greatly enlarged to reach “*individual disloyal utterances.*” Nine more offenses were added. Such prosecutions as have been passed upon in the Supreme Court decisions have not, however, brought the broader prohibitions of the amended act under its scrutiny. It cannot be said on authority, for instance, whether “*abusive language about… the uniform of the Army of the United States*” (one of the crimes under the amended act), spoken by a perspiring second lieutenant on a sticky August day about his leather puttees, is given immunity by the free speech clause Constitution or not. But while the cases decided by the Supreme Court under this statute by no means give us a complete text-book on free speech, they are worth noticing somewhat in detail, for they are the most important authority we have.

**Schenck v. United States** affirmed the conviction of Schenck, general secretary of the Socialist party, for conspiracy to cause and attempt to cause insubordination in the military forces and to obstruct enlistment service. Schenck was found to have been instrumental in sending out a circular, which attacked the conscription act, to men who had been called and accepted for military service. From the reported decision it appears that the defendant did not deny that the jury could have found the circular was intended to induce drafted men to obstruct the operation of the selective service law.

Mr. Justice Holmes, delivering the unanimous opinion of the court, made clear two points: first, the right of free speech, under which Schenck claimed immunity, is not an absolute and unchanging thing. War does make a difference. “*When a nation is at war many things that might be said in time of peace are such a hindrance to its efforts that their utterance will not be endured so long as men fight.*” Where the lawmaking body may draw the line we are not told; this question was not before the court. The defense seems to have admitted that Congress could lawfully penalize interference with fighting forces. The only question then was, how far could the law go in punishing a conspiracy for attempting to interfere?

The second important thing done in this decision is to lay down a test of liability for speech:

> “*The question in every case is whether the words are used in such circumstances and are of such a nature as to create **a clear and present danger** that they will bring about the substantive evils that Congress had a right to prevent.*“
>
> 249 US 47, 39 Sup. Ct. Rep. 2

This is very important; the liability is not to be found in the general effect of the words, nor in what may be thought to be their dangerous tendency. Instead, the test is similar to the common law liability for attempt to commit a crime — the act done by the wrongdoer must have come dangerously near to success. “Success” in this instance would be the substantive evil specified by Congress in the statute, interference with fighting forces of the country in war-time.

In two other cases the same month, March, I919, the unanimous court, again through Mr. Justice Holmes, reiterated the same criterion of “clear and present danger,” in affirming the conviction of Frohwerk, of the Missouri Staats-Zeitung (**Frohwerk v. United States**), and that of Eugene Debs (**Debs v. United States**). The Debs case has been unpopular in some quarters on ground that the accused was convicted merely because the jury thought the speech, upon which the charges against him were based, had perhaps some general tendency (as distinguished from a clear and present danger) to bring about resistance to the draft. Whether or not that is the fact, the Supreme Court does not change its first statement of the law governing liability for speech.

In November, I919, was decided the case of **Abrams v. United States**[,](https://en.wikipedia.org/wiki/Abrams_v._United_States) probably the most widely known of all the Espionage cases, the conduct of which has provoked much adverse discussion. The defendants in this case had prepared and distributed circulars for the purpose of opposing participation by the United States in the campaign against the Bolshevik government. The circulars were abusive of the president, denounced an alleged union of capitalism and militarism in the allied nations, and made the stock appeal to the workers for a general strike as a reply to, the “barbaric intervention”. The defendants were convicted under the amended Espionage Act, and the conviction affirmed by a divided Supreme Court, Justices Holmes and Brandeis dissenting. Despite the fact that the judges disagreed, it is difficult to put a finger on the exact difference between majority and minority as to the law. The dissenters urged that there was no evidence on which a jury of reasonable men could find against the defendants. “*The surreptitious publishing of a silly leaflet an unknown man*” could not present any immediate danger of interference with the success of government arms, thought the minority. The majority opinion spends little time in discussing the law, seeming to assume constitutional points settled by the previous cases already mentioned. It denounces the conduct of the defendants and deems the evidence sufficient to sustain their conviction. Professor Chafee’s able discussion of the history of the case makes one believe that great injustice has been done the individuals condemned to spend the best part of their lives in jail. But the majority’s opinion does not write that injustice into the law, at least so far as the language goes. It might as well have been a memorandum decision affirming the conviction, for all the help it gives in defining constitutional limits of free speech. The dissent of Mr. Justice Holmes, whether right or wrong in his view of the facts, is a fine expression of pragmatic legal philosophy and well deserves to be called “a literary and judicial classic.” It has been widely quoted, but it is eloquent enough to deserve repetition of an excerpt which is worth several readings:

> “Persecution for the expression of opinions seems to me perfectly logical. If you have no doubt of your premises or your power, and want a certain result with all your heart, you naturally express your wishes in law and sweep away all opposition. To allow opposition by speech seems to indicate that you think the speech impotent, as when a man says that he has squared the circle, or that you do not care wholeheartedly for the result, or that you doubt either your power or your premises. But when men have realized that time has upset many fighting faiths, they may come to believe even more than they believe the very foundations of their own conduct, that the ultimate good desired is better reached by free trade in ideas — that the best test of truth is the power of the thought to get itself accepted in the competition of the market, and that truth is the only ground upon which their wishes safely can be carried out. That, at any rate, is the theory of our Constitution. It is an experiment, as all life is an experiment. 1 Every year, if not every day, we have to wager our salvation upon some prophecy based upon imperfect knowledge. While that experiment is part of our system, I think that we should be eternally vigilant against attempts to check the expression of opinions that we loath and believe to be fraught with death, unless they so imminently threaten immediate interference with the lawful pressing purposes of the law that an immediate check is required to save the country… Only the emergency that makes it immediately dangerous to leave the correction of evil counsels to time warrants making any exception to the sweeping command, ‘*Congress shall make no law abridging the freedom of speech*.’… I regret that I cannot put into more impressive words my belief that in their conviction upon this indictment the defendants were deprived of rights under the Constitution of the United States.”

In March, I920, we have the last two important Espionage decisions. In each, Justices Holmes and Brandeis dissent. The first case, that of **Schaefer v. United States**, affirmed the conviction of officers of an obscure Pennsylvania concern publishing a weak little German newspaper. Again the majority opinion discusses facts for the most part. Mr. Justice McKenna, speaking for the majority of the court, says that when free speech or any right “*becomes wrong by excess is somewhat elusive of definition*,” and he does not tell us where he will draw the line. Mr. Justice Brandeis reemphasizes the “clear and present danger” criterion of liability, and the majority do not dispute his test.

It seems to the writer that the last case decided, **Pierce v. United States**[,](https://supreme.justia.com/cases/federal/us/252/239/) March 8, 1920. is the most important decision since the Schenck case, the first under the act. It was a particularly striking one on its facts, and even a reading of the decision of the majority of the court, which sustained the conviction of the defendants, makes one feel that the punishing of the prisoners was very harsh.

The act done by the defendants was the distribution of a pamphlet sent out from Socialist headquarters to the Albany, New York, “local” for distribution. When the literature first arrived the question of its distribution was brought up, and acting on the advice of a lawyer member, the Albany group voted to postpone their circulation of the matter until the outcome of a Maryland prosecution involving the same pamphlet, was determined. The Maryland judge ordered an acquittal of the defendants in the prosecution before him. It seemed safe, therefore, to go ahead in Albany, and this was done. But the distributors were arrested there, a jury readily convicted them, and their conviction was affirmed by the Supreme Court.

The literature which brought these men to grief was a four-page leaflet written by Irvin St. John Tucker, an Episcopal clergyman, who, as Mr. Justice Brandeis points out, was a man of sufficient prominence to have been included in “Who’s Who in America” for 1916-1917. The pamphlet pictured the horrors of the war, though not more vividly than some of the descriptions and pictures that a benevolent censor permitted to come before our eyes from official sources. It argued that the misery depicted was the logical outcome of the refusal of the people to accept Socialism. It called attention to rising food prices, stated that “*The attorney general of the United States is so busy sending to prison men who do not stand up when ‘The Star-Spangled Banner’ is played that he has no time to protect the food supply from gamblers.*” Though no harsher than charges made by opponents since, this must have been a sore point with the prosecution, for it was felt necessary to show that civilians were not compelled by law to stand when the National Anthem was played.

Injustice may have been done the particular individuals involved. That is a question that could only be fairly passed upon after examination of the whole record of the case in upper and lower courts. Even then opinions might well differ. But it seems to the writer that the decision is important because the majority opinion, this time through the very able Mr. Justice Pitney, adopts the doctrines technically known as “indirect causation” and “constructive intent” as a source of liability. If the majority of the court does adopt them, then the decision is most important and the Espionage Act has become a most effective silencer of all but the most polite discussion for all war-time periods until it is repealed.

The doctrines mentioned are of long standing, but for a hundred and twenty years had not been applied in the United States. Their meaning can be easily explained. Admit that the evil the statute is aimed to prevent is one regarding which Congress has power to exercise preventive measures, causing insubordination in the army, for instance. What words come within the penalty of the law? May all speech which might be said to have some tendency, however remote, to bring about acts in violation of law be punished, or only words which directly incite to acts in violation of law? Suppose that a man criticizes army food, do not his words have some tendency, at least in the mind of a jury with a strong imagination and in thorough sympathy with the war, to cause unrest and subsequent insubordination among soldiers? And it wouldn’t matter, would it, whether the words were said directly to a soldier, or to a woman’s club some of whose members had relatives or friends in the army? Under this doctrine of “indirect causation” words can be punished for supposed bad tendency long before the probability arises that they will break into unlawful acts. It is obvious that this test of liability is in sharp contrast with the “clear and present danger” rule of Mr. Justice Holmes. It has far-reaching consequences. What about the man who denounces an excess profits tax bill? Do not his words have a tendency to encourage another to violate the law? What of the Arizona statesman who is reported to have said that if the United States Government gave Caranza permission to take troops through his State he hoped the people would prevent their passage. Did his words not have a “tendency” to provoke violence? Any person of influence who expresses an opinion in some way remotely encourages another to act in accordance with the opinion expressed.

Hand in hand with this “indirect causation” doctrine goes that of “constructive intent.” The only intent the defendant must have is intent to write or speak the words he did. If the words have a bad tendency we will presume the man intended unlawful consequences, on the ground that he is presumed to intend the consequences of his acts. Now we have many places in the law where a man is liable for consequences even when he did not specifically intend them. If he shot off a gun at random in a crowded and killed someone, he certainly could not escape punishment by saying he didn’t intend to kill his victim. We can say that he is presumed to intend the natural consequence of his act, which is pure fiction. We may accurately say that specific intent to hit the very person he did is not by law required in order to hold him liable. But often crimes do require a specific intent, and if they do, such intent must be proved. When a penal statute such as the Espionage Act, makes certain speech a crime, such as advocating curtailment of production of things necessary to to the prosecution of the war, “*with intent… to hinder… the United States in the prosecution of the war,*” must not the words in their literal sense? To go back to the answer of Mr. Holmes in the Abrams case:

> “They would be absurd in any other. A patriot might think that we were wasting money on aeroplanes, or making more cannon of a certain kind than we needed, and might advocate curtailment with success; yet even if it turned out that the curtailment hindered the United States in the prosecution of the war, no one would hold such conduct a crime.”

“Constructive intent” and “indirect causation” had appeared in lower federal court decisions under the Espionage Act. Does the Supreme Court adopt them in the Pierce case? Says Mr. Justice Pitney:

> “Whether the statements contained in the pamphlets had a natural tendency to produce the forbidden consequences… was a question to be determined… by the jury… It was shown without dispute that the defendants distributed the pamphlet — ‘The Price We Pay’ — with full understanding of its contents; and this of itself furnished a ground for attributing to them an intent to bring about… any and all such consequences as reasonably might be anticipated from its distribution.”

If the majority of our highest court are applying the “indirect causation” and “constructive intent” tests as a basis for liability under the Espionage Act, we have an easy explanation for the division of that body through the group of decisions beginning with the Abrams case.

This ends the discussion of the constitutional right of free speech by our highest court. We probably shall have no more light upon it from this source in the immediate future.

In determining what is the final effect of these adjudications on the law of free speech, we should bear in mind the following: (I) That the Espionage Act is a war-time statute, and the court has emphasized a difference between the limits of speech in war and peace; (2) If the majority of the court has adopted the “indirect causation” and “constructive intent” doctrines they have not in so many words squarely overruled the Schenck case with its criterion of “clear and present danger” and told the minority that they were doing so, and why; (3) At subsequent time the disagreements in the cases may be explained as pertaining to the facts only and the minority’s exposition of the law may be taken as the doctrine court.

Finally, may we not be skeptical whether, in this present era of “social” thought and outlook, the right of the minority to say what it pleases will get the vigorous protection against the majority’s desire to dictate what shall be said that it would have received in days when individualistic notions were stronger? The recalcitrant minority is being compelled constantly to subject itself to many restrictions upon its liberty in doing acts heretofore considered perfectly lawful. The one time sacred right of freedom of contract is fettered in every motion. Laws regulate hours of labor, working conditions, the people one may hire, the minimum wage he is allowed to pay, the damages he must give for industrial accidents. One is told where he may build an apartment house and where he may not. His children must be vaccinated, inspected, and psychologically tested before they can go to school. If he is a venereal suspect he is rushed willy nilly to a hospital for inspection and treatment. **Purchase of intoxicants is prevented by a constitutional amendment;** even the buying of the innocuous “Camel” or “Fatima” [cigarettes] involves a breach of the law in many States. All of this in the name of protection to society — as interpreted by the majority.

Courts are upholding such “social” legislation with increasing sympathy, which is what we wish them to do. The majority opinion in **Lochner v. New York**, the New York bakers’ case, seems a long way off. But will not the same kind of argument and the same line of thought which upholds a law which restricts a man in the contracts he may make, or limits him in the use to which he may lawfully put his real estate, uphold a law limiting the exercise tongue when the majority so wills it?

Granted the question of freedom of speech is one of social values, will not the advocates of free speech, as the champions of minimum wage laws, have to convince their fellow citizens that their cause is righteous, that the benefits outweigh the dangers, that justice, fair play, and the common good demand that every side, no matter how unpopular, be given a hearing in the public’s forum? Reverting to Mr. Justice Holmes again, “*The best test of truth is the power of the thought to get itself accepted in the competition of the market.*” There is the place where the battle for restriction of freedom of contract has been won. If unrestricted speech cannot win in the same field, we shall probably have to get along without it.

\~~~

**1.** This thought is too much for Dean Wigmore to stomach, and in his discussion in 14 ILL. Law Rev., on p. 561, he sets it out in capitals with an abundance of exclamation points. He says: “…when found publicly recorded in an opinion of the Supreme Guardians of that Constitution, licensing propaganda which in the next case before the court may be directed against that Constitution itself, this language is ominous indeed.” Does Dean Wigmore mean that our Constitution is the last step possible in the evolution of government, and hence above criticism?